@@ -36,6 +36,7 @@ INST_ROCKSTAR=0 # Install the Rockstar halo finder?
 INST_SCIPY=0    # Install scipy?
 INST_H5PY=1     # Install h5py?
 INST_ASTROPY=0  # Install astropy?
+INST_CARTOPY=0  # Install cartopy?
 INST_NOSE=1     # Install nose?
 INST_NETCDF4=1  # Install netcdf4 and its python bindings?
 INST_HG=0       # Install Mercurial or not?
@@ -138,6 +139,7 @@ function write_config
     echo INST_EMBREE=${INST_EMBREE} >> ${CONFIG_FILE}
     echo INST_H5PY=${INST_H5PY} >> ${CONFIG_FILE}
     echo INST_ASTROPY=${INST_ASTROPY} >> ${CONFIG_FILE}
+    echo INST_CARTOPY=${INST_CARTOPY} >> ${CONFIG_FILE}
     echo INST_NOSE=${INST_NOSE} >> ${CONFIG_FILE}
 
     echo YT_DIR=${YT_DIR} >> ${CONFIG_FILE}
@@ -340,6 +342,10 @@ printf "%-18s = %s so I " "INST_ASTROPY" "${INST_ASTROPY}"
 get_willwont ${INST_ASTROPY}
 echo "be installing astropy"
 
+printf "%-18s = %s so I " "INST_CARTOPY" "${INST_CARTOPY}"
+get_willwont ${INST_CARTOPY}
+echo "be installing cartopy"
+
 printf "%-18s = %s so I " "INST_NOSE" "${INST_NOSE}"
 get_willwont ${INST_NOSE}
 echo "be installing nose"
@@ -512,6 +518,10 @@ if [ $INST_ASTROPY -ne 0 ]
 then
     YT_DEPS+=('astropy')
 fi
+if [ $INST_CARTOPY -ne 0 ]
+then
+    YT_DEPS+=('cartopy')
+fi
 YT_DEPS+=('conda-build')
 if [ $INST_PY3 -eq 0 ] && [ $INST_HG -eq 1 ]
 then
@@ -668,7 +678,7 @@ echo "    http://yt-project.org/"
 echo "    http://yt-project.org/data/      (Sample data)"
 echo "    http://yt-project.org/doc/       (Docs)"
 echo
-echo "    https://mail.python.org/mm3/archives/list/yt-users@python.org/"
+echo "    https://mail.python.org/archives/list/yt-users@python.org/"
 echo
 echo "You must now prepend the following folder to your PATH environment variable:"
 echo 
