@@ -1,10 +1,9 @@
 import os
 import sys
 
-from yt.analysis_modules.halo_analysis.api import \
-    HaloCatalog
 from yt.convenience import load
-from yt.testing import *
+from yt.frontends.halo_catalog.data_structures import \
+    HaloCatalogDataset
 from yt.utilities.answer_testing.framework import \
     FieldValuesTest, \
     requires_ds
@@ -33,6 +32,7 @@ def test_halo_finders():
                           "halo_catalogs", method,
                           "%s.0.h5" % method)
         ds = load(fn)
+        assert isinstance(ds, HaloCatalogDataset)
         for field in _fields:
             yield FieldValuesTest(ds, field, particle_type=True,
                                   decimals=decimals[method])
