@@ -27,6 +27,8 @@ from yt.utilities.physical_constants import \
     gravitational_constant_cgs
 from yt.utilities.physical_ratios import HUGE
 from yt.extern.six import add_metaclass
+from yt.utilities.exceptions import \
+    YTParticleTypeNotFound
 
 derived_quantity_registry = {}
 
@@ -107,7 +109,7 @@ class WeightedAverageQuantity(DerivedQuantity):
 
     Returns a YTQuantity for each field requested; if one,
     it returns a single YTQuantity, if many, it returns a list of YTQuantities
-    in order of the listed fields.  
+    in order of the listed fields.
 
     Where f is the field and w is the weight, the weighted average is
     Sum_i(f_i \* w_i) / Sum_i(w_i).
@@ -156,8 +158,8 @@ class TotalQuantity(DerivedQuantity):
 
     Parameters
     ----------
-    fields : field or list of fields
-        The field to be summed.
+    fields
+        The field or list of fields to be summed.
 
     Examples
     --------
@@ -188,7 +190,7 @@ class TotalQuantity(DerivedQuantity):
 class TotalMass(TotalQuantity):
     r"""
     Calculates the total mass of the object. Returns a YTArray where the
-    first element is total gas mass and the second element is total particle 
+    first element is total gas mass and the second element is total particle
     mass.
 
     Examples
@@ -228,6 +230,11 @@ class CenterOfMass(DerivedQuantity):
         Flag to include particles in the calculation.  Particles are ignored
         if not present.
         Default: False
+    particle_type: string
+        Flag to specify the field type of the particles to use. Useful for
+        particle-based codes where you don't want to use all of the particles
+        in your calculation.
+        Default: 'all'
 
     Examples
     --------
@@ -237,22 +244,24 @@ class CenterOfMass(DerivedQuantity):
     >>> print ad.quantities.center_of_mass()
 
     """
-    def count_values(self, use_gas = True, use_particles = False):
+    def count_values(self, use_gas = True, use_particles = False, particle_type="all"):
+        if use_particles and particle_type not in self.data_source.ds.particle_types:
+            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
         use_gas &= \
           (("gas", "cell_mass") in self.data_source.ds.field_info)
         use_particles &= \
-          (("all", "particle_mass") in self.data_source.ds.field_info)
+          ((particle_type, "particle_mass") in self.data_source.ds.field_info)
         self.num_vals = 0
         if use_gas:
             self.num_vals += 4
         if use_particles:
             self.num_vals += 4
 
-    def process_chunk(self, data, use_gas = True, use_particles = False):
+    def process_chunk(self, data, use_gas = True, use_particles = False, particle_type="all"):
         use_gas &= \
           (("gas", "cell_mass") in self.data_source.ds.field_info)
         use_particles &= \
-          (("all", "particle_mass") in self.data_source.ds.field_info)
+          ((particle_type, "particle_mass") in self.data_source.ds.field_info)
         vals = []
         if use_gas:
             vals += [(data["gas", ax] *
@@ -260,10 +269,10 @@ class CenterOfMass(DerivedQuantity):
                      for ax in 'xyz']
             vals.append(data["gas", "cell_mass"].sum(dtype=np.float64))
         if use_particles:
-            vals += [(data["all", "particle_position_%s" % ax] *
-                      data["all", "particle_mass"]).sum(dtype=np.float64)
+            vals += [(data[particle_type, "particle_position_%s" % ax] *
+                      data[particle_type, "particle_mass"]).sum(dtype=np.float64)
                      for ax in 'xyz']
-            vals.append(data["all", "particle_mass"].sum(dtype=np.float64))
+            vals.append(data[particle_type, "particle_mass"].sum(dtype=np.float64))
         return vals
 
     def reduce_intermediate(self, values):
@@ -298,6 +307,11 @@ class BulkVelocity(DerivedQuantity):
         Flag to include particles in the calculation.  Particles are ignored
         if not present.
         Default: True
+    particle_type: string
+        Flag to specify the field type of the particles to use. Useful for
+        particle-based codes where you don't want to use all of the particles
+        in your calculation.
+        Default: 'all'
 
     Examples
     --------
@@ -307,7 +321,9 @@ class BulkVelocity(DerivedQuantity):
     >>> print ad.quantities.bulk_velocity()
 
     """
-    def count_values(self, use_gas = True, use_particles = False):
+    def count_values(self, use_gas = True, use_particles = False, particle_type= "all"):
+        if use_particles and particle_type not in self.data_source.ds.particle_types:
+            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
         # This is a list now
         self.num_vals = 0
         if use_gas:
@@ -315,7 +331,7 @@ class BulkVelocity(DerivedQuantity):
         if use_particles:
             self.num_vals += 4
 
-    def process_chunk(self, data, use_gas = True, use_particles = False):
+    def process_chunk(self, data, use_gas = True, use_particles = False, particle_type= "all"):
         vals = []
         if use_gas:
             vals += [(data["gas", "velocity_%s" % ax] *
@@ -323,10 +339,10 @@ class BulkVelocity(DerivedQuantity):
                      for ax in 'xyz']
             vals.append(data["gas", "cell_mass"].sum(dtype=np.float64))
         if use_particles:
-            vals += [(data["all", "particle_velocity_%s" % ax] *
-                      data["all", "particle_mass"]).sum(dtype=np.float64)
+            vals += [(data[particle_type, "particle_velocity_%s" % ax] *
+                      data[particle_type, "particle_mass"]).sum(dtype=np.float64)
                      for ax in 'xyz']
-            vals.append(data["all", "particle_mass"].sum(dtype=np.float64))
+            vals.append(data[particle_type, "particle_mass"].sum(dtype=np.float64))
         return vals
 
     def reduce_intermediate(self, values):
@@ -405,15 +421,15 @@ class WeightedVariance(DerivedQuantity):
             my_mean = values[i]
             my_var2 = values[i + int(len(values) / 2)]
             all_mean = (my_weight * my_mean).sum(dtype=np.float64) / all_weight
-            rvals.append(self.data_source.ds.arr([(np.sqrt((my_weight * 
-                                                 (my_var2 + (my_mean - 
-                                                  all_mean)**2)).sum(dtype=np.float64) 
+            rvals.append(self.data_source.ds.arr([(np.sqrt((my_weight *
+                                                 (my_var2 + (my_mean -
+                                                  all_mean)**2)).sum(dtype=np.float64)
                                                   / all_weight)), all_mean]))
         return rvals
 
 class AngularMomentumVector(DerivedQuantity):
     r"""
-    Calculates the angular momentum vector, using gas and/or particles.
+    Calculates the angular momentum vector, using gas (grid-based) and/or particles.
 
     The angular momentum vector is the mass-weighted mean specific angular momentum.
     Returns a YTArray of the vector.
@@ -421,37 +437,52 @@ class AngularMomentumVector(DerivedQuantity):
     Parameters
     ----------
     use_gas : bool
-        Flag to include gas in the calculation.  Gas is ignored if not
+        Flag to include grid-based gas in the calculation. Gas is ignored if not
         present.
         Default: True
     use_particles : bool
         Flag to include particles in the calculation.  Particles are ignored
         if not present.
         Default: True
+    particle_type: string
+        Flag to specify the field type of the particles to use. Useful for
+        particle-based codes where you don't want to use all of the particles
+        in your calculation.
+        Default: 'all'
 
     Examples
     --------
 
+    # Find angular momentum vector of galaxy in grid-based isolated galaxy dataset
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
     >>> print ad.quantities.angular_momentum_vector()
 
+    # Find angular momentum vector of gas disk in particle-based dataset
+    >>> ds = load("FIRE_M12i_ref11/snapshot_600.hdf5")
+    >>> _, c = ds.find_max(('gas', 'density'))
+    >>> sp = ds.sphere(c, (10, 'kpc'))
+    >>> print sp.quantities.angular_momentum_vector(use_gas=False, use_particles=True, particle_type='PartType0')
+
     """
-    def count_values(self, use_gas=True, use_particles=True):
+    def count_values(self, use_gas=True, use_particles=True, particle_type = "all"):
+        if use_particles and particle_type not in self.data_source.ds.particle_types:
+            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
         num_vals = 0
         # create the index if it doesn't exist yet
         self.data_source.ds.index
+        self.particle_type = particle_type
         self.use_gas = use_gas & \
             (("gas", "cell_mass") in self.data_source.ds.field_info)
         self.use_particles = use_particles & \
-            (("all", "particle_mass") in self.data_source.ds.field_info)
+            ((self.particle_type, "particle_mass") in self.data_source.ds.field_info)
         if self.use_gas:
             num_vals += 4
         if self.use_particles:
             num_vals += 4
         self.num_vals = num_vals
 
-    def process_chunk(self, data, **kwargs):
+    def process_chunk(self, data, use_gas = True, use_particles = False, particle_type= "all"):
         rvals = []
         if self.use_gas:
             rvals.extend([(data["gas", "specific_angular_momentum_%s" % axis] *
@@ -459,10 +490,10 @@ class AngularMomentumVector(DerivedQuantity):
                           for axis in "xyz"])
             rvals.append(data["gas", "cell_mass"].sum(dtype=np.float64))
         if self.use_particles:
-            rvals.extend([(data["all", "particle_specific_angular_momentum_%s" % axis] *
-                           data["all", "particle_mass"]).sum(dtype=np.float64) \
+            rvals.extend([(data[self.particle_type, "particle_specific_angular_momentum_%s" % axis] *
+                           data[self.particle_type, "particle_mass"]).sum(dtype=np.float64) \
                           for axis in "xyz"])
-            rvals.append(data["all", "particle_mass"].sum(dtype=np.float64))
+            rvals.append(data[self.particle_type, "particle_mass"].sum(dtype=np.float64))
         return rvals
 
     def reduce_intermediate(self, values):
@@ -481,14 +512,15 @@ class Extrema(DerivedQuantity):
     r"""
     Calculates the min and max value of a field or list of fields.
     Returns a YTArray for each field requested.  If one, a single YTArray
-    is returned, if many, a list of YTArrays in order of field list is 
+    is returned, if many, a list of YTArrays in order of field list is
     returned.  The first element of each YTArray is the minimum of the
     field and the second is the maximum of the field.
 
     Parameters
     ----------
-    fields : field or list of fields
-        The field over which the extrema are to be calculated.
+    fields
+        The field or list of fields over which the extrema are to be
+        calculated.
     non_zero : bool
         If True, only positive values are considered in the calculation.
         Default: False
@@ -530,6 +562,7 @@ class Extrema(DerivedQuantity):
                 for mis, mas in zip(values[::2], values[1::2])]
 
 class SampleAtMaxFieldValues(DerivedQuantity):
+    _sign = -1
     r"""
     Calculates the maximum value and returns whichever fields are asked to be
     sampled.
@@ -561,7 +594,7 @@ class SampleAtMaxFieldValues(DerivedQuantity):
 
     def process_chunk(self, data, field, sample_fields):
         field = data._determine_fields(field)[0]
-        ma = array_like_field(data, -HUGE, field)
+        ma = array_like_field(data, self._sign*HUGE, field)
         vals = [array_like_field(data, -1, sf) for sf in sample_fields]
         maxi = -1
         if data[field].size > 0:
@@ -604,6 +637,7 @@ class MaxLocation(SampleAtMaxFieldValues):
         return rv
 
 class SampleAtMinFieldValues(SampleAtMaxFieldValues):
+    _sign = 1
     r"""
     Calculates the minimum value and returns whichever fields are asked to be
     sampled.
@@ -677,23 +711,29 @@ class SpinParameter(DerivedQuantity):
         Flag to include particles in the calculation.  Particles are ignored
         if not present.
         Default: True
+    particle_type : str
+        Particle type to be used for Center of mass calculation when use_particle
+        = True.
+        Default: all
 
     Examples
     --------
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.center_of_mass()
+    >>> print ad.quantities.spin_parameter()
 
     """
     def count_values(self, **kwargs):
         self.num_vals = 3
 
-    def process_chunk(self, data, use_gas=True, use_particles=True):
+    def process_chunk(self, data, use_gas=True, use_particles=True, particle_type= "all"):
+        if use_particles and particle_type not in self.data_source.ds.particle_types:
+            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
         use_gas &= \
           (("gas", "cell_mass") in self.data_source.ds.field_info)
         use_particles &= \
-          (("all", "particle_mass") in self.data_source.ds.field_info)
+          ((particle_type, "particle_mass") in self.data_source.ds.field_info)
         e = data.ds.quan(0., "erg")
         j = data.ds.quan(0., "g*cm**2/s")
         m = data.ds.quan(0., "g")
@@ -703,10 +743,10 @@ class SpinParameter(DerivedQuantity):
             j += data["gas", "angular_momentum_magnitude"].sum(dtype=np.float64)
             m += data["gas", "cell_mass"].sum(dtype=np.float64)
         if use_particles:
-            e += (data["all", "particle_velocity_magnitude"]**2 *
-                  data["all", "particle_mass"]).sum(dtype=np.float64)
-            j += data["all", "particle_angular_momentum_magnitude"].sum(dtype=np.float64)
-            m += data["all", "particle_mass"].sum(dtype=np.float64)
+            e += (data[particle_type, "particle_velocity_magnitude"]**2 *
+                  data[particle_type, "particle_mass"]).sum(dtype=np.float64)
+            j += data[particle_type, "particle_angular_momentum_magnitude"].sum(dtype=np.float64)
+            m += data[particle_type, "particle_mass"].sum(dtype=np.float64)
         return (e, j, m)
 
     def reduce_intermediate(self, values):
