@@ -40,7 +40,7 @@ def test_ellipsoid():
                 e0 = e0s[:,i]
                 tilt = tilts[i]
                 ell = ds.ellipsoid(c, A, B, C, e0, tilt)
-                yield assert_array_less, ell["radius"], A
+                assert_array_less(ell["radius"], A)
                 p = np.array([ell[ax] for ax in 'xyz'])
                 dot_evec = [np.zeros_like(ell["radius"]) for i in range(3)]
                 vecs = [ell._e0, ell._e1, ell._e2]
@@ -55,4 +55,4 @@ def test_ellipsoid():
                 dist = 0
                 for ax_i in range(3):
                     dist += dot_evec[ax_i]**2.0 / mags[ax_i]**2.0
-                yield assert_array_less, dist, 1.0
+                assert_array_less(dist, 1.0)
