@@ -63,7 +63,7 @@ def test_region_and_particles():
     assert_equal(expected, result)
 
 ISOGAL = 'IsolatedGalaxy/galaxy0030/galaxy0030'
-    
+
 @requires_file(ISOGAL)
 def test_region_chunked_read():
     # see #2104
@@ -72,4 +72,19 @@ def test_region_chunked_read():
     sp = ds.sphere((0.5, 0.5, 0.5), (2, "kpc"))
     dense_sp = sp.cut_region(['obj["H_p0_number_density"]>= 1e-2'])
     dense_sp.quantities.angular_momentum_vector()
-    
+
+@requires_file(ISOGAL)
+def test_chained_cut_region():
+    # see Issue #2233
+    ds = load(ISOGAL)
+    base = ds.disk([0.5,0.5,0.5], [0,0,1], (4,"kpc"), (10,"kpc"))
+    c1 = "(obj['cylindrical_r'].in_units('kpc') > 2.0)"
+    c2 = "(obj['density'].to('g/cm**3') > 1e-26)"
+
+    cr12  = base.cut_region([c1, c2])
+    cr1   = base.cut_region([c1])
+    cr12c =  cr1.cut_region([c2])
+
+    field = ('index', 'cell_volume')
+    assert_equal(cr12.quantities.total_quantity(field),
+                 cr12c.quantities.total_quantity(field))
