@@ -25,12 +25,18 @@ from .field_plugin_registry import \
 from yt.funcs import \
     just_one
 
+from yt.geometry.geometry_handler import \
+    is_curvilinear
+
 from .vector_operations import \
     create_magnitude_field, \
     create_squared_field
 
 @register_field_plugin
 def setup_fluid_vector_fields(registry, ftype = "gas", slice_info = None):
+    # Current implementation for gradient is not valid for curvilinear geometries
+    if is_curvilinear(registry.ds.geometry): return
+
     unit_system = registry.ds.unit_system
     # slice_info would be the left, the right, and the factor.
     # For example, with the old Enzo-ZEUS fields, this would be:
@@ -111,7 +117,7 @@ def setup_fluid_vector_fields(registry, ftype = "gas", slice_info = None):
         vx = data[ftype, "relative_velocity_x"]
         vy = data[ftype, "relative_velocity_y"]
         f  = ((vy[sl_right,sl_center,sl_center] -
-               vx[sl_left,sl_center,sl_center]) /
+               vy[sl_left,sl_center,sl_center]) /
               (div_fac*just_one(data["index", "dx"])))
         f -= ((vx[sl_center,sl_right,sl_center] -
                vx[sl_center,sl_left,sl_center]) /
