@@ -1102,8 +1102,9 @@ class CastroDataset(BoxlibDataset):
                 if any(b in line for b in bcs):
                     p, v = line.strip().split(":")
                     self.parameters[p] = v.strip()
-                if "git hash" in line:
-                    # line format: codename git hash:  the-hash
+                if "git describe" in line or "git hash" in line:
+                    # Castro release 17.02 and later - line format: codename git describe:  the-hash
+                    # Castro before release 17.02    - line format: codename git hash:  the-hash
                     fields = line.split(":")
                     self.parameters[fields[0]] = fields[1].strip()
                 line = next(f)
@@ -1113,6 +1114,8 @@ class CastroDataset(BoxlibDataset):
             # skip the "====..." line
             line = next(f)
             for line in f:
+                if line.strip() == "" or "fortin parameters" in line:
+                    continue
                 p, v = line.strip().split("=")
                 self.parameters[p] = v.strip()
 
@@ -1329,7 +1332,7 @@ def _guess_pcast(vals):
     v = vals.split()[0]
     try:
         float(v.upper().replace("D", "E"))
-    except:
+    except Exception:
         pcast = str
         if v in ("F", "T"):
             pcast = bool
@@ -1380,10 +1383,18 @@ def _read_header(raw_file, field):
         header_file = level_file + "/" + field + "_H"
         with open(header_file, "r") as f:
         
-            # skip the first five lines
-            for _ in range(5):
-                f.readline()
-
+            f.readline()  # version
+            f.readline()  # how
+            f.readline()  # ncomp
+            nghost_lines = f.readline().strip().split()
+            try:
+                ng = int(nghost_lines[0])
+                nghost = np.array([ng, ng, ng])
+            except ValueError:
+                nghosts = nghost_lines[0][1:-1].split(",")
+                nghost = np.array([int(ng) for ng in nghosts])
+            f.readline()  # num boxes
+            
             # read boxes
             boxes = []
             for line in f:
@@ -1406,7 +1417,7 @@ def _read_header(raw_file, field):
             all_file_names += file_names
             all_offsets += offsets
 
-    return all_boxes, all_file_names, all_offsets
+    return nghost, all_boxes, all_file_names, all_offsets
 
 
 class WarpXHeader(object):
@@ -1446,6 +1457,9 @@ class WarpXHeader(object):
             line = f.readline()
             while line:
                 line = line.strip().split()
+                if (len(line) == 1):
+                    line = f.readline()
+                    continue
                 self.data["species_%d" % i] = [float(val) for val in line]
                 i = i + 1
                 line = f.readline()
@@ -1480,9 +1494,11 @@ class WarpXHierarchy(BoxlibHierarchy):
         self.field_list += [('raw', f) for f in self.raw_fields]
         self.raw_field_map = {}
         self.ds.nodal_flags = {}
+        self.raw_field_nghost = {}
         for field_name in self.raw_fields:
-            boxes, file_names, offsets = _read_header(self.raw_file, field_name)
-            self.raw_field_map[field_name] = (boxes, file_names, offsets) 
+            nghost, boxes, file_names, offsets = _read_header(self.raw_file, field_name)
+            self.raw_field_map[field_name] = (boxes, file_names, offsets)
+            self.raw_field_nghost[field_name] = nghost
             self.ds.nodal_flags[field_name] = np.array(boxes[0][2])
 
 
