@@ -14,17 +14,14 @@ Fields specific to Enzo
 #-----------------------------------------------------------------------------
 
 import numpy as np
-
-from yt.funcs import mylog
 from yt.fields.field_info_container import \
     FieldInfoContainer
-from yt.units.yt_array import \
-    YTArray
 from yt.utilities.physical_constants import \
-    mh, me, mp, \
-    mass_sun_cgs
+    me, \
+    mp
 
 b_units = "code_magnetic"
+e_units = "code_magnetic/c"
 ra_units = "code_length / code_time**2"
 rho_units = "code_mass / code_length**3"
 vel_units = "code_velocity"
@@ -38,6 +35,7 @@ known_species_names = {
     'H2I'     : 'H2',
     'H2II'    : 'H2_p1',
     'HM'      : 'H_m1',
+    'HeH'     : 'HeH',
     'DI'      : 'D',
     'DII'     : 'D_p1',
     'HDI'     : 'HD',
@@ -53,6 +51,18 @@ known_species_names = {
     'OIX'     : 'O_p8',
 }
 
+NODAL_FLAGS = {
+    'BxF': [1, 0, 0],
+    'ByF': [0, 1, 0],
+    'BzF': [0, 0, 1],
+    'Ex': [0, 1, 1],
+    'Ey': [1, 0, 1],
+    'Ez': [1, 1, 0],
+    'AvgElec0': [0, 1, 1],
+    'AvgElec1': [1, 0, 1],
+    'AvgElec2': [1, 1, 0],
+}
+
 class EnzoFieldInfo(FieldInfoContainer):
     known_other_fields = (
         ("Cooling_Time", ("s", ["cooling_time"], None)),
@@ -62,9 +72,20 @@ class EnzoFieldInfo(FieldInfoContainer):
         ("HeI_kph", ("1/code_time", [], None)),
         ("HeII_kph", ("1/code_time", [], None)),
         ("H2I_kdiss", ("1/code_time", [], None)),
-        ("Bx", (b_units, ["magnetic_field_x"], None)),
-        ("By", (b_units, ["magnetic_field_y"], None)),
-        ("Bz", (b_units, ["magnetic_field_z"], None)),
+        ("HM_kph", ("1/code_time", [], None)),
+        ("H2II_kdiss", ("1/code_time", [], None)),
+        ("Bx", (b_units, [], None)),
+        ("By", (b_units, [], None)),
+        ("Bz", (b_units, [], None)),
+        ("BxF", (b_units, [], None)),
+        ("ByF", (b_units, [], None)),
+        ("BzF", (b_units, [], None)),
+        ("Ex", (e_units, [], None)),
+        ("Ey", (e_units, [], None)),
+        ("Ez", (e_units, [], None)),
+        ("AvgElec0", (e_units, [], None)),
+        ("AvgElec1", (e_units, [], None)),
+        ("AvgElec2", (e_units, [], None)),
         ("RadAccel1", (ra_units, ["radiation_acceleration_x"], None)),
         ("RadAccel2", (ra_units, ["radiation_acceleration_y"], None)),
         ("RadAccel3", (ra_units, ["radiation_acceleration_z"], None)),
@@ -75,7 +96,7 @@ class EnzoFieldInfo(FieldInfoContainer):
         ("y-velocity", (vel_units, ["velocity_y"], None)),
         ("z-velocity", (vel_units, ["velocity_z"], None)),
         ("RaySegments", ("", ["ray_segments"], None)),
-        ("PhotoGamma", (ra_units, ["photo_gamma"], None)),
+        ("PhotoGamma", ("eV/code_time", ["photo_gamma"], None)),
         ("PotentialField", ("code_velocity**2", ["gravitational_potential"], None)),
         ("Density", (rho_units, ["density"], None)),
         ("Metal_Density", (rho_units, ["metal_density"], None)),
@@ -118,6 +139,12 @@ class EnzoFieldInfo(FieldInfoContainer):
         slice_info = (sl_left, sl_right, div_fac)
         super(EnzoFieldInfo, self).__init__(ds, field_list, slice_info)
 
+        # setup nodal flag information
+        for field in NODAL_FLAGS:
+            if ('enzo', field) in self:
+                finfo = self['enzo', field]
+                finfo.nodal_flag = np.array(NODAL_FLAGS[field])
+
     def add_species_field(self, species):
         # This is currently specific to Enzo.  Hopefully in the future we will
         # have deeper integration with other systems, such as Dengo, to provide
@@ -127,7 +154,7 @@ class EnzoFieldInfo(FieldInfoContainer):
         # off, we add the species field itself.  Then we'll add a few more
         # items...
         #
-        self.add_output_field(("enzo", "%s_Density" % species),
+        self.add_output_field(("enzo", "%s_Density" % species), sampling_type="cell",
                            take_log=True,
                            units="code_mass/code_length**3")
         yt_name = known_species_names[species]
@@ -143,15 +170,17 @@ class EnzoFieldInfo(FieldInfoContainer):
                          if sp in known_species_names]
         def _electron_density(field, data):
             return data["Electron_Density"] * (me/mp)
-        self.add_field(("gas", "El_density"),
+        self.add_field(("gas", "El_density"), sampling_type="cell",
                        function = _electron_density,
-                       units = "g/cm**3")
+                       units = self.ds.unit_system["density"])
         for sp in species_names:
             self.add_species_field(sp)
             self.species_names.append(known_species_names[sp])
         self.species_names.sort()  # bb #1059
 
     def setup_fluid_fields(self):
+        from yt.fields.magnetic_field import \
+            setup_magnetic_field_aliases
         # Now we conditionally load a few other things.
         params = self.ds.parameters
         multi_species = params.get("MultiSpecies", None)
@@ -161,8 +190,10 @@ class EnzoFieldInfo(FieldInfoContainer):
         if multi_species > 0 or dengo == 1:
             self.setup_species_fields()
         self.setup_energy_field()
+        setup_magnetic_field_aliases(self, "enzo", ["B%s" % ax for ax in "xyz"])
 
     def setup_energy_field(self):
+        unit_system = self.ds.unit_system
         # We check which type of field we need, and then we add it.
         ge_name = None
         te_name = None
@@ -186,21 +217,38 @@ class EnzoFieldInfo(FieldInfoContainer):
             te_name = "TotalEnergy"
 
         if hydro_method == 2:
-            self.add_output_field(("enzo", te_name),
+            self.add_output_field(("enzo", te_name), sampling_type="cell",
                 units="code_velocity**2")
             self.alias(("gas", "thermal_energy"), ("enzo", te_name))
-
+            def _ge_plus_kin(field, data):
+                ret = data[te_name] + 0.5*data["velocity_x"]**2.0
+                if data.ds.dimensionality > 1:
+                    ret += 0.5*data["velocity_y"]**2.0
+                if data.ds.dimensionality > 2:
+                    ret += 0.5*data["velocity_z"]**2.0
+                return ret
+            self.add_field(
+                ("gas", "total_energy"), sampling_type="cell",
+                function = _ge_plus_kin,
+                units = unit_system["specific_energy"])
         elif dual_energy == 1:
             self.add_output_field(
-                ("enzo", ge_name),
+                ("enzo", te_name), sampling_type="cell",
+                units = "code_velocity**2")
+            self.alias(
+                ("gas", "total_energy"),
+                ("enzo", te_name),
+                units = unit_system["specific_energy"])
+            self.add_output_field(
+                ("enzo", ge_name), sampling_type="cell",
                 units="code_velocity**2")
             self.alias(
                 ("gas", "thermal_energy"),
                 ("enzo", ge_name),
-                units = "erg/g")
+                units = unit_system["specific_energy"])
         elif hydro_method in (4, 6):
             self.add_output_field(
-                ("enzo", te_name),
+                ("enzo", te_name), sampling_type="cell",
                 units="code_velocity**2")
             # Subtract off B-field energy
             def _sub_b(field, data):
@@ -212,13 +260,16 @@ class EnzoFieldInfo(FieldInfoContainer):
                 ret -= data["magnetic_energy"]/data["density"]
                 return ret
             self.add_field(
-                ("gas", "thermal_energy"),
-                function=_sub_b, units = "erg/g")
+                ("gas", "thermal_energy"), sampling_type="cell",
+                function=_sub_b, units = unit_system["specific_energy"])
         else: # Otherwise, we assume TotalEnergy is kinetic+thermal
             self.add_output_field(
-                ("enzo", te_name),
+                ("enzo", te_name), sampling_type="cell",
                 units = "code_velocity**2")
-            self.alias(("gas", "total_energy"), ("enzo", te_name))
+            self.alias(
+                ("gas", "total_energy"),
+                ("enzo", te_name),
+                units = unit_system["specific_energy"])
             def _tot_minus_kin(field, data):
                 ret = data[te_name] - 0.5*data["velocity_x"]**2.0
                 if data.ds.dimensionality > 1:
@@ -227,23 +278,22 @@ class EnzoFieldInfo(FieldInfoContainer):
                     ret -= 0.5*data["velocity_z"]**2.0
                 return ret
             self.add_field(
-                ("gas", "thermal_energy"),
+                ("gas", "thermal_energy"), sampling_type="cell",
                 function = _tot_minus_kin,
-                units = "erg/g")
+                units = unit_system["specific_energy"])
         if multi_species == 0 and 'Mu' in params:
             def _number_density(field, data):
                 return data['gas', 'density']/(mp*params['Mu'])
             self.add_field(
-                ("gas", "number_density"),
+                ("gas", "number_density"), sampling_type="cell",
                 function = _number_density,
-                units="1/cm**3")
+                units=unit_system["number_density"])
 
     def setup_particle_fields(self, ptype):
 
         def _age(field, data):
             return data.ds.current_time - data["creation_time"]
-        self.add_field((ptype, "age"), function = _age,
-                           particle_type = True,
+        self.add_field((ptype, "age"), sampling_type="particle", function = _age,
                            units = "yr")
 
         super(EnzoFieldInfo, self).setup_particle_fields(ptype)
