@@ -314,10 +314,12 @@ class ExodusIIDataset(Dataset):
         with self._handle.open_ds() as ds:
             if "coord" not in ds.variables:
                 coords = np.array([ds.variables["coord%s" % ax][:]
-                                   for ax in coord_axes]).transpose().copy()
+                                   for ax in coord_axes]
+                                  ).transpose().astype("f8")
             else:
                 coords = np.array([coord for coord in
-                                   ds.variables["coord"][:]]).transpose().copy()
+                                   ds.variables["coord"][:]]
+                                  ).transpose().astype("f8")
             return coords
 
     def _apply_displacement(self, coords, mesh_id):
@@ -397,5 +399,4 @@ class ExodusIIDataset(Dataset):
             with Dataset(filename, keepweakref=True) as f:
                 f.variables['connect1']
             return True
-        except:
-            pass
+        except Exception: pass
