@@ -69,7 +69,7 @@ class IOHandlerExodusII(BaseIOHandler):
                     mesh_ids = [mesh.mesh_id + 1 for mesh in self.ds.index.mesh_union]
                     objs = [mesh for mesh in self.ds.index.mesh_union]
                 else:
-                    mesh_ids = [int(ftype[-1])]
+                    mesh_ids = [int(ftype.replace("connect",""))]
                     chunk = chunks[mesh_ids[0] - 1]
                     objs = chunk.objs
                 if fname in self.node_fields:
