@@ -45,7 +45,7 @@ def parse_unit_dimension(unit_dimension):
     >>> print parse_unit_dimension(magnetic_field)
     'kg**1*s**-2*A**-1'
     """
-    if len(unit_dimension) is not 7:
+    if len(unit_dimension) != 7:
         mylog.error("SI must have 7 base dimensions!")
     unit_dimension = np.asarray(unit_dimension, dtype=np.int)
     dim = []
