@@ -67,7 +67,7 @@ class OWLSDataset(GadgetHDF5Dataset):
                 if vg in fileh["/"]:
                     valid = False                    
             fileh.close()
-        except:
+        except Exception:
             valid = False
             pass
         return valid
