@@ -304,6 +304,7 @@ class HydroFieldFileHandler(FieldFileHandler):
 
             # We get no fields for old-style hydro file descriptor
             ok = len(fields) > 0
+
         elif cls.config_field and ytcfg.has_section(cls.config_field):
             # Or this is given by the config
             cfg = ytcfg.get(cls.config_field, 'fields')
@@ -346,14 +347,14 @@ class HydroFieldFileHandler(FieldFileHandler):
                 if nvar == 11:
                     fields = ["Density",
                               "x-velocity", "y-velocity", "z-velocity",
-                              "x-Bfield-left", "y-Bfield-left", "z-Bfield-left",
-                              "x-Bfield-right", "y-Bfield-right", "z-Bfield-right",
+                              "B_x_left","B_y_left","B_z_left",
+                              "B_x_right","B_y_right","B_z_right",
                               "Pressure"]
                 if nvar > 11:
                     fields = ["Density",
                               "x-velocity", "y-velocity", "z-velocity",
-                              "x-Bfield-left", "y-Bfield-left", "z-Bfield-left",
-                              "x-Bfield-right", "y-Bfield-right", "z-Bfield-right",
+                              "B_x_left","B_y_left","B_z_left",
+                              "B_x_right","B_y_right","B_z_right",
                               "Pressure", "Metallicity"]
             mylog.debug("No fields specified by user; automatically setting fields array to %s"
                         % str(fields))
