@@ -102,9 +102,11 @@ class RockstarDataset(Dataset):
         self.hubble_constant = hvals['h0']
         self.omega_lambda = hvals['Ol']
         self.omega_matter = hvals['Om']
-        cosmo = Cosmology(self.hubble_constant,
-                          self.omega_matter, self.omega_lambda)
-        self.current_time = cosmo.hubble_time(self.current_redshift).in_units("s")
+        cosmo = Cosmology(hubble_constant=self.hubble_constant,
+                          omega_matter=self.omega_matter,
+                          omega_lambda=self.omega_lambda)
+        self.current_time = cosmo.lookback_time(
+            self.current_redshift, 1e6).in_units("s")
         self.periodicity = (True, True, True)
         self.particle_types = ("halos")
         self.particle_types_raw = ("halos")
