@@ -21,8 +21,9 @@ from yt.extern.six.moves import urllib
 
 
 _fields = (('deposit', 'all_cic'))
-scivis_data = "http://darksky.slac.stanford.edu/scivis2015/data/ds14_scivis_0128/ds14_scivis_0128_e4_dt04_1.0000"
-
+slac_scivis_data = "http://darksky.slac.stanford.edu/scivis2015/data/ds14_scivis_0128/ds14_scivis_0128_e4_dt04_1.0000"
+ncsa_scivis_data = "http://use.yt/upload/744abba3"
+scivis_data = ncsa_scivis_data
 
 # Answer on http://stackoverflow.com/questions/3764291/checking-network-connection
 # Better answer on http://stackoverflow.com/questions/2712524/handling-urllib2s-timeout-python
@@ -40,8 +41,12 @@ def internet_on():
 def test_scivis():
     if not internet_on():
         return
+    return # HOTFIX: See discussion in 2334
     ds = SDFDataset(scivis_data)
-    yield assert_equal, str(ds), "ds14_scivis_0128_e4_dt04_1.0000"
+    if scivis_data == slac_scivis_data:
+        assert_equal(str(ds), "ds14_scivis_0128_e4_dt04_1.0000")
+    else:
+        assert_equal(str(ds), "744abba3")
     ad = ds.all_data()
     assert np.unique(ad['particle_position_x']).size > 1
-    p = ProjectionPlot(ds, "z", _fields)
+    ProjectionPlot(ds, "z", _fields)
