@@ -325,8 +325,10 @@ class IOHandlerTipsyBinary(BaseIOHandler):
         for f in glob.glob(data_file.filename + '.*'):
             afield = f.rsplit('.')[-1]
             filename = data_file.filename + '.' + afield
-            if not os.path.exists(filename): continue
+            if not os.path.exists(filename):
+                continue
             self._aux_fields.append(afield)
+        skip_afields = []
         for afield in self._aux_fields:
             filename = data_file.filename + '.' + afield
             # We need to do some fairly ugly detection to see what format the
@@ -338,6 +340,11 @@ class IOHandlerTipsyBinary(BaseIOHandler):
                            count=1) != tot_parts:
                 with open(filename, 'rb') as f:
                     header_nparts = f.readline()
+                    try:
+                        header_nparts = int(header_nparts)
+                    except ValueError:
+                        skip_afields.append(afield)
+                        continue
                     if int(header_nparts) != tot_parts:
                         raise RuntimeError
                 self._aux_pdtypes[afield] = "ascii"
@@ -349,8 +356,9 @@ class IOHandlerTipsyBinary(BaseIOHandler):
                 else:
                     self._aux_pdtypes[afield] = np.dtype([('aux', endian + 'f')])
             else:
-                raise RuntimeError
-
+                skip_afields.append(afield)
+        for afield in skip_afields:
+            self._aux_fields.remove(afield)
         # Add the auxiliary fields to each ptype we have
         for ptype in self._ptypes:
             if any([ptype == field[0] for field in self._field_list]):
