@@ -112,6 +112,28 @@ class CoordinateHandler(object):
     def convert_from_spherical(self, coord):
         raise NotImplementedError
 
+    _data_projection = None
+    @property
+    def data_projection(self):
+        if self._data_projection is not None:
+            return self._data_projection
+        dpj = {}
+        for ax in self.axis_order:
+            dpj[ax] = None
+        self._data_projection = dpj
+        return dpj
+
+    _data_transform = None
+    @property
+    def data_transform(self):
+        if self._data_transform is not None:
+            return self._data_transform
+        dtx = {}
+        for ax in self.axis_order:
+            dtx[ax] = None
+        self._data_transform = dtx
+        return dtx
+
     _axis_name = None
     @property
     def axis_name(self):
@@ -248,6 +270,13 @@ class CoordinateHandler(object):
         display_center = self.convert_to_cartesian(center)
         return center, display_center
 
+    def sanitize_buffer_fill_values(self, buff):
+        """Replace nans with +inf in buff, if all valid values are positive"""
+        # In buffer with only positive values, maplotlib will raise a warning
+        # if nan is used as a filler, while it tolerates np.inf just fine
+        minval = buff[~np.isnan(buff)].min()
+        if minval >= 0:
+            buff[np.isnan(buff)] = np.inf
 
 def cartesian_to_cylindrical(coord, center = (0,0,0)):
     c2 = np.zeros_like(coord)
