@@ -5,7 +5,11 @@ import numpy as np
 from yt.testing import \
     fake_amr_ds, \
     assert_equal, \
-    assert_almost_equal
+    assert_almost_equal, \
+    add_noise_fields
+
+from yt.utilities.answer_testing.framework import GenericImageTest
+from yt import SlicePlot
 
 # Our canonical tests are that we can access all of our fields and we can
 # compute our volume correctly.
@@ -30,3 +34,21 @@ def test_cylindrical_coordinates():
     assert_equal(dd["index", "path_element_z"], dd["index", "dz"])
     assert_equal(dd["index", "path_element_theta"],
                  dd["index", "r"] * dd["index", "dtheta"])
+
+def test_noise_plots():
+    ds = fake_amr_ds(geometry="cylindrical")
+    add_noise_fields(ds)
+
+    def create_image(filename_prefix):
+        fields = ['noise%d' % i for i in range(4)]
+
+        p = SlicePlot(ds, 'z', fields)
+        p.save('%s_log' % filename_prefix)
+
+        p.set_log('all', False)
+        p.save('%s_lin' % filename_prefix)
+
+    test = GenericImageTest(ds, create_image, 12)
+    test.prefix = "test_noise_plot_lin"
+    test_noise_plots.__name__ = test.description
+    yield test
