@@ -110,7 +110,7 @@ def get_latex_representation(expr, registry):
     for ex in expr.free_symbols:
         try:
             symbol_table[ex] = registry.lut[str(ex)][3]
-        except:
+        except Exception:
             symbol_table[ex] = r"\rm{" + str(ex).replace('_', '\ ') + "}"
 
     # invert the symbol table dict to look for keys with identical values
@@ -130,7 +130,7 @@ def get_latex_representation(expr, registry):
     prefix = None
     if isinstance(expr, Mul):
         coeffs = expr.as_coeff_Mul()
-        if coeffs[0] == 1 or not isinstance(coeffs[0], Float):
+        if coeffs[0] == 1 or not isinstance(coeffs[0], Number):
             pass
         else:
             expr = coeffs[1]
@@ -146,7 +146,7 @@ def get_latex_representation(expr, registry):
     else:
         return latex_repr
 
-unit_text_transform = (auto_positive_symbol, rationalize, auto_number)
+unit_text_transform = (auto_positive_symbol, auto_number, rationalize)
 
 class Unit(Expr):
     """
@@ -440,7 +440,7 @@ class Unit(Expr):
         # test first for 'is' equality to avoid expensive sympy operation
         if self.dimensions is other_unit.dimensions:
             return True
-        return (self.dimensions / other_unit.dimensions) == sympy_one
+        return self.dimensions == other_unit.dimensions
 
     @property
     def is_dimensionless(self):
