@@ -366,7 +366,7 @@ class AMRKDTree(ParallelAnalysisInterface):
 
         That is they start from the lower left and proceed to upper
         right varying the third index most frequently. Note that the
-        center cell (i,j,k) is ommitted.
+        center cell (i,j,k) is omitted.
 
         """
         ci = np.array(ci)
@@ -422,7 +422,7 @@ class AMRKDTree(ParallelAnalysisInterface):
 
         That is they start from the lower left and proceed to upper
         right varying the third index most frequently. Note that the
-        center cell (i,j,k) is ommitted.
+        center cell (i,j,k) is omitted.
 
         """
         position = np.array(position)
@@ -446,8 +446,7 @@ class AMRKDTree(ParallelAnalysisInterface):
                     try:
                         f.create_dataset("/brick_%s_%s" % (hex(i),field),
                                          data = node.data.my_data[fi].astype('float64'))
-                    except:
-                        pass
+                    except Exception: pass
         f.close()
         del f
         if self.comm.rank != (self.comm.size-1):
@@ -479,8 +478,7 @@ class AMRKDTree(ParallelAnalysisInterface):
             self._initialized=True
             f.close()
             del f
-        except:
-            pass
+        except Exception: pass
         if self.comm.rank != (self.comm.size-1):
             self.comm.send_array([0],self.comm.rank+1, tag=self.comm.rank)
 
