@@ -6,7 +6,7 @@ and featuring time and redshift conversion functions from Enzo.
 """
 
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013-2014, yt Development Team.
+# Copyright (c) yt Development Team. All rights reserved.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -16,6 +16,8 @@ and featuring time and redshift conversion functions from Enzo.
 import functools
 import numpy as np
 
+from yt.funcs import \
+     issue_deprecation_warning
 from yt.units import dimensions
 from yt.units.unit_registry import \
      UnitRegistry
@@ -24,15 +26,15 @@ from yt.units.yt_array import \
      YTQuantity
 
 from yt.utilities.physical_constants import \
-    gravitational_constant_cgs as G, \
-    speed_of_light_cgs
+     gravitational_constant_cgs as G, \
+     speed_of_light_cgs
 
 class Cosmology(object):
     r"""
     Create a cosmology calculator to compute cosmological distances and times.
 
     For an explanation of the various cosmological measures, see, for example 
-    Hogg (1999, http://xxx.lanl.gov/abs/astro-ph/9905116).
+    Hogg (1999, https://arxiv.org/abs/astro-ph/9905116).
 
     WARNING: Cosmological distance calculations return values that are either
     in the comoving or proper frame, depending on the specific quantity.  For
@@ -52,6 +54,8 @@ class Cosmology(object):
     omega_lambda : the fraction of the energy density of the Universe in 
         a cosmological constant.
         Default: 0.73.
+    omega_radiation : the fraction of the energy density of the Universe in
+        relativistic matter at redshift zero.
     omega_curvature : the fraction of the energy density of the Universe in 
         curvature.
         Default: 0.0.
@@ -75,12 +79,13 @@ class Cosmology(object):
 
     >>> from yt.utilities.cosmology import Cosmology
     >>> co = Cosmology()
-    >>> print(co.hubble_time(0.0).in_units("Gyr"))
+    >>> print(co.t_from_z(0.0).in_units("Gyr"))
 
     """
     def __init__(self, hubble_constant = 0.71,
                  omega_matter = 0.27,
                  omega_lambda = 0.73,
+                 omega_radiation = 0.0,
                  omega_curvature = 0.0,
                  unit_registry = None,
                  unit_system = "cgs",
@@ -88,6 +93,7 @@ class Cosmology(object):
                  w_0 = -1.0,
                  w_a = 0.0):
         self.omega_matter = float(omega_matter)
+        self.omega_radiation = float(omega_radiation)
         self.omega_lambda = float(omega_lambda)
         self.omega_curvature = float(omega_curvature)
         if unit_registry is None:
@@ -113,7 +119,8 @@ class Cosmology(object):
         The distance corresponding to c / h, where c is the speed of light 
         and h is the Hubble parameter in units of 1 / time.
         """
-        return self.quan((speed_of_light_cgs / self.hubble_constant)).in_base(self.unit_system)
+        return self.quan(speed_of_light_cgs /
+                         self.hubble_constant).in_base(self.unit_system)
 
     def comoving_radial_distance(self, z_i, z_f):
         r"""
@@ -194,8 +201,8 @@ class Cosmology(object):
         >>> print(co.comoving_volume(0., 1.).in_units("Gpccm**3"))
 
         """
-        if (self.omega_curvature > 0):
-             return (2 * np.pi * np.power(self.hubble_distance(), 3) /
+        if (self.omega_curvature > 1e-10):
+            return (2 * np.pi * np.power(self.hubble_distance(), 3) /
                      self.omega_curvature * 
                      (self.comoving_transverse_distance(z_i, z_f) /
                       self.hubble_distance() * 
@@ -206,8 +213,8 @@ class Cosmology(object):
                             self.comoving_transverse_distance(z_i, z_f) /
                             self.hubble_distance()) /
                             np.sqrt(self.omega_curvature))).in_base(self.unit_system)
-        elif (self.omega_curvature < 0):
-             return (2 * np.pi * np.power(self.hubble_distance(), 3) /
+        elif (self.omega_curvature < -1e-10):
+            return (2 * np.pi * np.power(self.hubble_distance(), 3) /
                      np.fabs(self.omega_curvature) * 
                      (self.comoving_transverse_distance(z_i, z_f) /
                       self.hubble_distance() * 
@@ -219,7 +226,7 @@ class Cosmology(object):
                            self.hubble_distance()) /
                       np.sqrt(np.fabs(self.omega_curvature)))).in_base(self.unit_system)
         else:
-             return (4 * np.pi *
+            return (4 * np.pi *
                      np.power(self.comoving_transverse_distance(z_i, z_f), 3) /\
                      3).in_base(self.unit_system)
 
@@ -321,7 +328,15 @@ class Cosmology(object):
     
     def hubble_time(self, z, z_inf=1e6):
         r"""
-        The age of the Universe at a given redshift.
+        The inverse of the Hubble parameter.
+
+        WARNING: this function is incorrect and has been deprecated!
+
+        This function currently returns the age of the Universe at a
+        given redshift instead of the inverse of the Hubble parameter.
+        To get the correct behavior, do the following:
+
+        >>> (1 / co.hubble_parameter(z)).in_units('Gyr')
 
         Parameters
         ----------
@@ -338,12 +353,12 @@ class Cosmology(object):
         >>> co = Cosmology()
         >>> print(co.hubble_time(0.).in_units("Gyr"))
 
-        See Also
-        --------
-
-        t_from_z
-
         """
+        issue_deprecation_warning(
+            'The hubble_time function is incorrect and has been deprecated! ' +
+            'Instead, do the following:\n' +
+            '>>> print (1 / co.hubble_parameter(z)).to(\'Gyr\')\n' +
+            'If you want the age of the Universe, use the t_from_z function.')
         return (trapzint(self.age_integrand, z, z_inf) /
                 self.hubble_constant).in_base(self.unit_system)
 
@@ -366,10 +381,8 @@ class Cosmology(object):
         >>> print(co.critical_density(0).in_units("Msun/Mpc**3"))
         
         """
-        return (3.0 / 8.0 / np.pi * 
-                self.hubble_constant**2 / G *
-                ((1 + z)**3.0 * self.omega_matter + 
-                 self.omega_lambda)).in_base(self.unit_system)
+        return (3.0 * self.hubble_parameter(z)**2 /
+                8.0 / np.pi / G).in_base(self.unit_system)
 
     def hubble_parameter(self, z):
         r"""
@@ -388,10 +401,11 @@ class Cosmology(object):
         >>> print(co.hubble_parameter(1.0).in_units("km/s/Mpc"))
 
         """
-        return self.hubble_constant.in_base(self.unit_system) * self.expansion_factor(z)
+        return (self.hubble_constant.in_base(self.unit_system) *
+                self.expansion_factor(z))
 
     def age_integrand(self, z):
-        return (1 / (z + 1) / self.expansion_factor(z))
+        return 1. / (z + 1) / self.expansion_factor(z)
 
     def expansion_factor(self, z):
         r"""
@@ -411,12 +425,14 @@ class Cosmology(object):
         else:
             dark_factor = 1.0
 
-        return np.sqrt(self.omega_matter * ((1 + z)**3.0) + 
-                       self.omega_curvature * ((1 + z)**2.0) + 
-                       (self.omega_lambda * dark_factor))
+        zp1 = 1 + z
+        return np.sqrt(self.omega_matter    * zp1**3 +
+                       self.omega_curvature * zp1**2 +
+                       self.omega_radiation * zp1**4 +
+                       self.omega_lambda    * dark_factor)
 
     def inverse_expansion_factor(self, z):
-        return 1 / self.expansion_factor(z)
+        return 1. / self.expansion_factor(z)
 
     def path_length_function(self, z):
         return ((1 + z)**2) * self.inverse_expansion_factor(z)
@@ -424,103 +440,45 @@ class Cosmology(object):
     def path_length(self, z_i, z_f):
         return trapzint(self.path_length_function, z_i, z_f)
 
-    def z_from_t(self, my_time):
+    def t_from_a(self, a):
         """
-        Compute the redshift from time after the big bang.  This is based on
-        Enzo's CosmologyComputeExpansionFactor.C, but altered to use physical
-        units.
+        Compute the age of the Universe for a given scale factor.
 
         Parameters
         ----------
-        my_time : float
-            Age of the Universe in seconds.
+        a : float
+            Scale factor.
 
         Examples
         --------
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.z_from_t(4.e17))
+        >>> print(co.t_from_a(1.).in_units("Gyr"))
 
         """
 
-        omega_curvature = 1.0 - self.omega_matter - self.omega_lambda
+        # Interpolate from a table of log(a) vs. log(t)
+        la = np.log10(a)
+        la_i = min(-6, np.asarray(la).min() - 3)
+        la_f = np.asarray(la).max()
+        bins_per_dex = 1000
+        n_bins = int((la_f - la_i) * bins_per_dex + 1)
+        la_bins = np.linspace(la_i, la_f, n_bins)
+        z_bins = 1. / np.power(10, la_bins) - 1
 
-        OMEGA_TOLERANCE = 1e-5
-        ETA_TOLERANCE = 1.0e-10
+        # Integrate in redshift.
+        lt = trapezoid_cumulative_integral(self.age_integrand, z_bins)
 
-        # Convert the time to Time * H0.
+        # Add a minus sign because we've switched the integration limits.
+        table = InterpTable(la_bins[1:], np.log10(-lt))
+        t = np.power(10, table(la))
 
-        if not isinstance(my_time, YTArray):
-            my_time = self.quan(my_time, "s")
-
-        t0 = (my_time.in_units("s") *
-              self.hubble_constant.in_units("1/s")).to_ndarray()
- 
-        # 1) For a flat universe with omega_matter = 1, it's easy.
- 
-        if ((np.fabs(self.omega_matter-1) < OMEGA_TOLERANCE) and
-            (self.omega_lambda < OMEGA_TOLERANCE)):
-            a = np.power(my_time/self.initial_time, 2.0/3.0)
- 
-        # 2) For omega_matter < 1 and omega_lambda == 0 see
-        #    Peebles 1993, eq. 13-3, 13-10.
-        #    Actually, this is a little tricky since we must solve an equation
-        #    of the form eta - np.sinh(eta) + x = 0..
- 
-        if ((self.omega_matter < 1) and 
-            (self.omega_lambda < OMEGA_TOLERANCE)):
-            x = 2*t0*np.power(1.0 - self.omega_matter, 1.5) / \
-                self.omega_matter;
- 
-            # Compute eta in a three step process, first from a third-order
-            # Taylor expansion of the formula above, then use that in a fifth-order
-            # approximation.  Then finally, iterate on the formula itself, solving for
-            # eta.  This works well because parts 1 & 2 are an excellent approximation
-            # when x is small and part 3 converges quickly when x is large. 
- 
-            eta = np.power(6*x, 1.0/3.0)                # part 1
-            eta = np.power(120*x/(20+eta*eta), 1.0/3.0) # part 2
-            for i in range(40):                      # part 3
-                eta_old = eta
-                eta = np.arcsinh(eta + x)
-                if (np.fabs(eta-eta_old) < ETA_TOLERANCE): 
-                    break
-                if (i == 39):
-                    print("No convergence after %d iterations." % i)
- 
-            # Now use eta to compute the expansion factor (eq. 13-10, part 2).
- 
-            a = self.omega_matter/(2.0*(1.0 - self.omega_matter))*\
-                (np.cosh(eta) - 1.0)
-
-        # 3) For omega_matter > 1 and omega_lambda == 0, use sin/cos.
-        #    Easy, but skip it for now.
- 
-        if ((self.omega_matter > 1) and 
-            (self.omega_lambda < OMEGA_TOLERANCE)):
-            print("Never implemented in Enzo, not implemented here.")
-            return 0
- 
-        # 4) For flat universe, with non-zero omega_lambda, see eq. 13-20.
- 
-        if ((np.fabs(omega_curvature) < OMEGA_TOLERANCE) and
-            (self.omega_lambda > OMEGA_TOLERANCE)):
-            a = np.power(self.omega_matter / 
-                         (1 - self.omega_matter), 1.0/3.0) * \
-                np.power(np.sinh(1.5 * np.sqrt(1.0 - self.omega_matter)*\
-                                     t0), 2.0/3.0)
-
-
-        redshift = (1.0/a) - 1.0
-
-        return redshift
+        return (t / self.hubble_constant).in_base(self.unit_system)
 
     def t_from_z(self, z):
         """
-        Compute the age of the Universe from redshift.  This is based on Enzo's
-        CosmologyComputeTimeFromRedshift.C, but altered to use physical units.  
-        Similar to hubble_time, but using an analytical function.
+        Compute the age of the Universe for a given redshift.
 
         Parameters
         ----------
@@ -534,48 +492,94 @@ class Cosmology(object):
         >>> co = Cosmology()
         >>> print(co.t_from_z(0.).in_units("Gyr"))
 
-        See Also
+        """
+
+        return self.t_from_a(1. / (1. + z))
+
+    def a_from_t(self, t):
+        """
+        Compute the scale factor for a given age of the Universe.
+
+        Parameters
+        ----------
+        t : YTQuantity or float
+            Time since the Big Bang.  If a float is given, units are
+            assumed to be seconds.
+
+        Examples
         --------
 
-        hubble_time
-        
+        >>> from yt.utilities.cosmology import Cosmology
+        >>> co = Cosmology()
+        >>> print(co.a_from_t(4.e17))
+
         """
-        omega_curvature = 1.0 - self.omega_matter - self.omega_lambda
- 
-        # 1) For a flat universe with omega_matter = 1, things are easy.
- 
-        if ((self.omega_matter == 1.0) and (self.omega_lambda == 0.0)):
-            t0 = 2.0/3.0/np.power(1+z, 1.5)
- 
-        # 2) For omega_matter < 1 and omega_lambda == 0 see
-        #    Peebles 1993, eq. 13-3, 13-10.
- 
-        if ((self.omega_matter < 1) and (self.omega_lambda == 0)):
-            eta = np.arccosh(1 + 
-                             2*(1-self.omega_matter)/self.omega_matter/(1+z))
-            t0 = self.omega_matter/ \
-              (2*np.power(1.0-self.omega_matter, 1.5))*\
-              (np.sinh(eta) - eta)
- 
-        # 3) For omega_matter > 1 and omega_lambda == 0, use sin/cos.
- 
-        if ((self.omega_matter > 1) and (self.omega_lambda == 0)):
-            eta = np.arccos(1 - 2*(1-self.omega_matter)/self.omega_matter/(1+z))
-            t0 = self.omega_matter/(2*np.power(1.0-self.omega_matter, 1.5))*\
-                (eta - np.sin(eta))
- 
-        # 4) For flat universe, with non-zero omega_lambda, see eq. 13-20.
- 
-        if ((np.fabs(omega_curvature) < 1.0e-3) and (self.omega_lambda != 0)):
-            t0 = 2.0/3.0/np.sqrt(1-self.omega_matter)*\
-                np.arcsinh(np.sqrt((1-self.omega_matter)/self.omega_matter)/ \
-                               np.power(1+z, 1.5))
-  
-        # Now convert from Time * H0 to time.
-  
-        my_time = t0 / self.hubble_constant
-    
-        return my_time.in_base(self.unit_system)
+
+        if not isinstance(t, YTArray):
+            t = self.arr(t, 's')
+        lt = np.log10((t * self.hubble_constant).to(""))
+
+        # Interpolate from a table of log(a) vs. log(t)
+        # Make initial guess for bounds and widen if necessary.
+        la_i = -6
+        la_f = 6
+        bins_per_dex = 1000
+        iter = 0
+
+        while True:
+            good = True
+            n_bins = int((la_f - la_i) * bins_per_dex + 1)
+            la_bins = np.linspace(la_i, la_f, n_bins)
+            z_bins = 1. / np.power(10, la_bins) - 1
+
+            # Integrate in redshift.
+            lt_bins = trapezoid_cumulative_integral(
+                self.age_integrand, z_bins)
+
+            # Add a minus sign because we've switched the integration limits.
+            table = InterpTable(np.log10(-lt_bins), la_bins[1:])
+            la = table(lt)
+            # We want to have the la_bins lower bound be decently
+            # below the minimum calculated la values.
+
+            laa = np.asarray(la)
+            if laa.min() < la_i + 2:
+                la_i -= 3
+                good = False
+            if laa.max() > la_f:
+                la_f = laa.max() + 1
+                good = False
+            if good:
+                break
+            iter += 1
+            if iter > 10:
+                raise RuntimeError(
+                    "a_from_t calculation did not converge!")
+
+        a = np.power(10, table(lt))
+        return a
+
+    def z_from_t(self, t):
+        """
+        Compute the redshift for a given age of the Universe.
+
+        Parameters
+        ----------
+        t : YTQuantity or float
+            Time since the Big Bang.  If a float is given, units are
+            assumed to be seconds.
+
+        Examples
+        --------
+
+        >>> from yt.utilities.cosmology import Cosmology
+        >>> co = Cosmology()
+        >>> print(co.z_from_t(4.e17))
+
+        """
+
+        a = self.a_from_t(t)
+        return 1. / a - 1.
 
     def get_dark_factor(self, z):
         """
@@ -622,3 +626,24 @@ class Cosmology(object):
 def trapzint(f, a, b, bins=10000):
     zbins = np.logspace(np.log10(a + 1), np.log10(b + 1), bins) - 1
     return np.trapz(f(zbins[:-1]), x=zbins[:-1], dx=np.diff(zbins))
+
+def trapezoid_cumulative_integral(f, x):
+    """
+    Perform cumulative integration using the trapezoid rule.
+    """
+
+    fy = f(x)
+    return (0.5 * (fy[:-1] + fy[1:]) * np.diff(x)).cumsum()
+
+class InterpTable(object):
+    """
+    Generate a function to linearly interpolate from provided arrays.
+    """
+    def __init__(self, x, y):
+        self.x = x
+        self.y = y
+
+    def __call__(self, val):
+        i = np.clip(np.digitize(val, self.x) - 1, 0, self.x.size - 2)
+        slope = (self.y[i+1] - self.y[i]) / (self.x[i+1] - self.x[i])
+        return slope * (val - self.x[i]) + self.y[i]
