@@ -64,7 +64,7 @@ def lru_cache(maxsize=100, typed=False, make_key = _make_key):
     View the cache statistics named tuple (hits, misses, maxsize, currsize) with
     f.cache_info().  Clear the cache and statistics with f.cache_clear().
     Access the underlying function with f.__wrapped__.
-    See:  http://en.wikipedia.org/wiki/Cache_algorithms#Least_Recently_Used
+    See: <https://en.wikipedia.org/wiki/Cache_replacement_policies#Least_recently_used_(LRU)>
     """
 
     # Users should only access the lru_cache through its public API:
