@@ -14,11 +14,11 @@ Operation registry class
 #-----------------------------------------------------------------------------
 
 import copy
-import types
+from yt.extern.six import string_types
 
 class OperatorRegistry(dict):
     def find(self, op, *args, **kwargs):
-        if isinstance(op, str):
+        if isinstance(op, string_types):
             # Lookup, assuming string or hashable object
             op = copy.deepcopy(self[op])
             op.args = args
