@@ -89,7 +89,7 @@ def enable_parallelism(suppress_logging=False, communicator=None):
     """
     This method is used inside a script to turn on MPI parallelism, via
     mpi4py.  More information about running yt in parallel can be found
-    here: http://yt-project.org/docs/3.0/analyzing/parallel_computation.html
+    here: https://yt-project.org/docs/3.0/analyzing/parallel_computation.html
 
     Parameters
     ----------
