@@ -14,9 +14,8 @@ API for yt.visualization
 #-----------------------------------------------------------------------------
 
 from .color_maps import \
-    add_cmap, \
+    add_colormap, \
     show_colormaps, \
-    add_cmap, \
     make_colormap
 
 from .particle_plots import \
