@@ -25,6 +25,7 @@ from .plot_window import PlotWindow
 from .profile_plotter import PhasePlot, ProfilePlot
 from yt.units.yt_array import YTQuantity
 from yt.units.unit_object import Unit
+from yt.funcs import issue_deprecation_warning
 
 def convert_frac_to_tex(string):
     frac_pos = string.find(r'\frac')
@@ -373,13 +374,13 @@ class DualEPS(object):
             _ylabel = pyxize_label(yaxis.label.get_text())
             # set log if necessary
             if subplot.get_xscale() == "log":
-                 _xlog = True 
+                _xlog = True 
             else:
-                 _xlog = False
+                _xlog = False
             if subplot.get_yscale() == "log":
-                 _ylog = True 
+                _ylog = True 
             else:
-                 _ylog = False
+                _ylog = False
             _tickcolor = None 
         elif isinstance(plot, PhasePlot):
             k = list(plot.plots.keys())[0]
@@ -799,7 +800,8 @@ class DualEPS(object):
 
     def arrow(self, size=0.2, label="", loc=(0.05,0.08), labelloc="top",
               color=pyx.color.cmyk.white,
-              linewidth=pyx.style.linewidth.normal):
+              linewidth=pyx.style.linewidth.normal,
+              rotation=0.0):
         r"""Draws an arrow in the current figure
 
         Parameters
@@ -811,6 +813,8 @@ class DualEPS(object):
         loc : tuple of floats
             Location of the left hand side of the arrow in units of
             the figure size.
+        rotation : float
+            Orientation angle of the arrow in units of degrees
         labelloc : string
             Location of the label with respect to the line.  Can be
             "top" or "bottom"
@@ -829,8 +833,8 @@ class DualEPS(object):
         """
         line = pyx.path.line(self.figsize[0]*loc[0],
                              self.figsize[1]*loc[1],
-                             self.figsize[0]*(loc[0]+size),
-                             self.figsize[1]*loc[1])
+                             self.figsize[0]*(loc[0]+size*np.cos(np.pi*rotation/180)),
+                             self.figsize[1]*(loc[1]+size*np.sin(np.pi*rotation/180)))
         self.canvas.stroke(line, [linewidth, color, pyx.deco.earrow()])
        
 
@@ -972,9 +976,9 @@ class DualEPS(object):
         elif format == "pdf":
             self.canvas.writePDFfile(filename)
         elif format == "png":
-             self.canvas.writeGSfile(filename+".png", "png16m", resolution=resolution)
+            self.canvas.writeGSfile(filename+".png", "png16m", resolution=resolution)
         elif format == "jpg":
-             self.canvas.writeGSfile(filename+".jpeg", "jpeg", resolution=resolution)
+            self.canvas.writeGSfile(filename+".jpeg", "jpeg", resolution=resolution)
         else:
             raise RuntimeError("format %s unknown." % (format))
             
@@ -1013,7 +1017,7 @@ def multiplot(ncol, nrow, yt_plots=None, fields=None, images=None,
         Labels for the y-axes
     colorbars : list of dicts
         Dicts that describe the type of colorbar to be used in each
-        figure.  Use the function return_cmap() to create these dicts.
+        figure.  Use the function return_colormap() to create these dicts.
     shrink_cb : float
         Factor by which the colorbar is shrunk.
     figsize : tuple of floats
@@ -1044,10 +1048,10 @@ def multiplot(ncol, nrow, yt_plots=None, fields=None, images=None,
     >>> images = ["density.jpg", "hi_density.jpg", "entropy.jpg",
     >>>           "special.jpg"]
     >>> cbs=[]
-    >>> cbs.append(return_cmap("arbre", "Density [cm$^{-3}$]", (0,10), False))
-    >>> cbs.append(return_cmap("kelp", "HI Density", (0,5), False))
-    >>> cbs.append(return_cmap("hot", r"Entropy [K cm$^2$]", (1e-2,1e6), True))
-    >>> cbs.append(return_cmap("Spectral", "Stuff$_x$!", (1,300), True))
+    >>> cbs.append(return_colormap("arbre", "Density [cm$^{-3}$]", (0,10), False))
+    >>> cbs.append(return_colormap("kelp", "HI Density", (0,5), False))
+    >>> cbs.append(return_colormap("hot", r"Entropy [K cm$^2$]", (1e-2,1e6), True))
+    >>> cbs.append(return_colormap("Spectral", "Stuff$_x$!", (1,300), True))
     >>> 
     >>> mp = multiplot(2,2, images=images, margins=(0.1,0.1),
     >>>                titles=["1","2","3","4"],
@@ -1275,7 +1279,7 @@ def multiplot_yt(ncol, nrow, plots, fields=None, **kwargs):
     >>>
     >>> p2 = SlicePlot(ds, 0, 'temperature')
     >>> p2.set_width(10, 'kpc')
-    >>> p2.set_cmap('temperature', 'hot')
+    >>> p2.set_colormap('temperature', 'hot')
     >>>
     >>> sph = ds.sphere(ds.domain_center, (10, 'kpc'))
     >>> p3 = PhasePlot(sph, 'radius', 'density', 'temperature',
@@ -1352,6 +1356,10 @@ def single_plot(plot, field=None, figsize=(12,12), cb_orient="right",
 
 #=============================================================================
 def return_cmap(cmap=None, label="", range=(0,1), log=False):
+    issue_deprecation_warning("Deprecated alias. Use return_colormap instead.")
+    return return_colormap(cmap=cmap, label=label, crange=range, log=log)
+
+def return_colormap(cmap=None, label="", range=(0,1), log=False):
     r"""Returns a dict that describes a colorbar.  Exclusively for use with
     multiplot.
 
@@ -1368,7 +1376,7 @@ def return_cmap(cmap=None, label="", range=(0,1), log=False):
 
     Examples
     --------
-    >>> cb = return_cmap("arbre", "Density [cm$^{-3}$]", (0,10), False)
+    >>> cb = return_colormap("arbre", "Density [cm$^{-3}$]", (0,10), False)
     """
     if cmap is None:
         cmap = ytcfg.get("yt", "default_colormap")
