@@ -23,6 +23,7 @@ from distutils.version import LooseVersion
 from nose.tools import assert_true
 
 from yt.testing import \
+    requires_file, \
     fake_random_ds, assert_equal, assert_rel_equal, assert_array_equal, \
     assert_array_almost_equal, assert_raises, assert_fname
 from yt.utilities.answer_testing.framework import \
@@ -510,8 +511,10 @@ def test_set_unit():
     assert str(slc.frb['gas', 'temperature'].units) == 'keV'
 
 WD = "WDMerger_hdf5_chk_1000/WDMerger_hdf5_chk_1000.hdf5"
+blast_wave = "amrvac/bw_2d0000.dat"
 
-@requires_ds(WD)
+@requires_file(WD)
+@requires_file(blast_wave)
 def test_plot_2d():
     # Cartesian
     ds = fake_random_ds((32,32,1), fields=('temperature',), units=('K',))
@@ -529,6 +532,12 @@ def test_plot_2d():
     slc2 = plot_2d(ds, "density", width=(30000.0, "km"))
     assert_array_equal(slc.frb['density'], slc2.frb['density'])
 
+    # Spherical
+    ds = data_dir_load(blast_wave)
+    slc = SlicePlot(ds, "phi", ["density"], width=(1, "unitary"))
+    slc2 = plot_2d(ds, "density", width=(1, "unitary"))
+    assert_array_equal(slc.frb['density'], slc2.frb['density'])
+
 def test_symlog_colorbar():
     ds = fake_random_ds(16)
 
