@@ -20,9 +20,13 @@ from .transfer_functions import TransferFunction, ColorTransferFunction, \
 from .image_handling import export_rgba, import_rgba, \
                            plot_channel, plot_rgb
 
-from .camera import Camera, PerspectiveCamera, StereoPairCamera, \
-    off_axis_projection, FisheyeCamera, MosaicFisheyeCamera, \
-    HEALpixCamera, InteractiveCamera, ProjectionCamera, \
-    SphericalCamera, StereoSphericalCamera
-
+from .camera import Camera
 from .transfer_function_helper import TransferFunctionHelper
+from .volume_rendering import volume_render, create_scene
+from .off_axis_projection import off_axis_projection
+from .scene import Scene
+from .render_source import VolumeSource, OpaqueSource, LineSource, \
+    BoxSource, PointSource, CoordinateVectorSource, GridSource, \
+    MeshSource
+from .zbuffer_array import ZBuffer
+from .interactive_vr_helpers import interactive_render
