@@ -762,7 +762,7 @@ class MeshSource(OpaqueSource):
         ----------
         cmap_name : string, optional
             An acceptable colormap.  See either yt.visualization.color_maps or
-            http://www.scipy.org/Cookbook/Matplotlib/Show_colormaps .
+            https://scipy-cookbook.readthedocs.io/items/Matplotlib_Show_colormaps.html .
         color_bounds : tuple of floats, optional
             The min and max to scale between.  Outlying values will be clipped.
 
