@@ -332,7 +332,7 @@ class Scene(object):
             out = np.clip(out[:, :, :3] / max_val, 0.0, 1.0) * 255
             out = np.concatenate(
                 [out.astype('uint8'), alpha[..., None]], axis=-1)
-            # not sure why we need rot90, but this makes the orentation
+            # not sure why we need rot90, but this makes the orientation
             # match the png writer
             ax.imshow(np.rot90(out), origin='lower')
             canvas.print_figure(fname, dpi=100)
@@ -396,8 +396,8 @@ class Scene(object):
         ...                                        horizontalalignment="center")]])
 
         """
-        import matplotlib.pyplot as plt
-
+        from yt.visualization._mpl_imports import \
+            FigureCanvasAgg, FigureCanvasPdf, FigureCanvasPS
         sources = list(itervalues(self.sources))
         rensources = [s for s in sources if isinstance(s, RenderSource)]
 
@@ -429,11 +429,10 @@ class Scene(object):
         ax = self._show_mpl(self._last_render.swapaxes(0, 1),
                             sigma_clip=sigma_clip, dpi=dpi)
         self._annotate(ax.axes, tf, rs, label=label, label_fmt=label_fmt)
-        plt.tight_layout()
 
         # any text?
         if text_annotate is not None:
-            f = plt.gcf()
+            f = self._render_figure
             for t in text_annotate:
                 xy = t[0]
                 string = t[1]
@@ -446,17 +445,31 @@ class Scene(object):
                 if "color" not in opt:
                     opt["color"] = "w"
 
-                plt.text(xy[0], xy[1], string,
-                         transform=f.transFigure, **opt)
+                ax.axes.text(xy[0], xy[1], string,
+                             transform=f.transFigure, **opt)
 
-        plt.savefig(fname, facecolor='black', pad_inches=0)
+        suffix = get_image_suffix(fname)
+
+        if suffix == ".png":
+            canvas = FigureCanvasAgg(self._render_figure)
+        elif suffix == ".pdf":
+            canvas = FigureCanvasPdf(self._render_figure)
+        elif suffix in (".eps", ".ps"):
+            canvas = FigureCanvasPS(self._render_figure)
+        else:
+            mylog.warning("Unknown suffix %s, defaulting to Agg", suffix)
+            canvas = self.canvas
+
+        self._render_figure.canvas = canvas
+        self._render_figure.tight_layout()
+        self._render_figure.savefig(fname, facecolor='black', pad_inches=0)
 
     def _show_mpl(self, im, sigma_clip=None, dpi=100):
-        import matplotlib.pyplot as plt
+        from matplotlib.figure import Figure
         s = im.shape
-        self._render_figure = plt.figure(1, figsize=(s[1]/float(dpi), s[0]/float(dpi)))
+        self._render_figure = Figure(figsize=(s[1]/float(dpi), s[0]/float(dpi)))
         self._render_figure.clf()
-        ax = plt.gca()
+        ax = self._render_figure.add_subplot(111)
         ax.set_position([0, 0, 1, 1])
 
         if sigma_clip is not None:
@@ -467,19 +480,18 @@ class Scene(object):
             del nz
         else:
             nim = im
-        axim = plt.imshow(nim[:,:,:3]/nim[:,:,:3].max(),
-                          interpolation="bilinear")
+        axim = ax.imshow(nim[:,:,:3]/nim[:,:,:3].max(),
+                         interpolation="bilinear")
 
         return axim
 
     def _annotate(self, ax, tf, source, label="", label_fmt=None):
-        import matplotlib.pyplot as plt
         ax.get_xaxis().set_visible(False)
         ax.get_xaxis().set_ticks([])
         ax.get_yaxis().set_visible(False)
         ax.get_yaxis().set_ticks([])
-        cb = plt.colorbar(ax.images[0], pad=0.0, fraction=0.05,
-                          drawedges=True, shrink=0.75)
+        cb = self._render_figure.colorbar(ax.images[0], pad=0.0, fraction=0.05,
+                                          drawedges=True)
         tf.vert_cbar(ax=cb.ax, label=label, label_fmt=label_fmt,
                      resolution=self.camera.resolution[0],
                      log_scale=source.log_field)
