@@ -18,17 +18,16 @@ import os.path
 import tempfile
 import shutil
 from yt.testing import \
-    fake_random_ds
+    fake_random_ds, \
+    assert_fname
 import numpy as np
-from yt.visualization.volume_rendering.api import \
+from yt.visualization.volume_rendering.old_camera import \
     PerspectiveCamera, StereoPairCamera, InteractiveCamera, ProjectionCamera, \
-    ColorTransferFunction, ProjectionTransferFunction
-from yt.visualization.tests.test_plotwindow import assert_fname
+    FisheyeCamera
+from yt.visualization.volume_rendering.api import ColorTransferFunction, \
+    ProjectionTransferFunction
 from unittest import TestCase
 
-# This toggles using a temporary directory. Turn off to examine images.
-use_tmpdir = True 
-
 
 def setup():
     """Test specific setup."""
@@ -37,8 +36,11 @@ def setup():
 
 
 class CameraTest(TestCase):
+    # This toggles using a temporary directory. Turn off to examine images.
+    use_tmpdir = True
+
     def setUp(self):
-        if use_tmpdir:
+        if self.use_tmpdir:
             self.curdir = os.getcwd()
             # Perform I/O in safe place instead of yt main dir
             self.tmpdir = tempfile.mkdtemp()
@@ -54,7 +56,7 @@ class CameraTest(TestCase):
         self.field = ("gas", "density")
 
     def tearDown(self):
-        if use_tmpdir:
+        if self.use_tmpdir:
             os.chdir(self.curdir)
             shutil.rmtree(self.tmpdir)
 
@@ -161,3 +163,10 @@ class CameraTest(TestCase):
             snap
         cam.snapshot('final.png')
         assert_fname('final.png')
+
+    def test_fisheye(self):
+        ds = self.ds
+        tf = self.setup_transfer_function('camera')
+        cam = FisheyeCamera(ds.domain_center, ds.domain_width[0],
+                            360.0, 256, transfer_function=tf, ds=ds)
+        cam.snapshot('fisheye.png')
