@@ -650,7 +650,7 @@ class ColorTransferFunction(MultiVariateTransferFunction):
             The alpha value height for the Gaussian
         colormap : string, optional
             An acceptable colormap.  See either yt.visualization.color_maps or
-            http://www.scipy.org/Cookbook/Matplotlib/Show_colormaps .
+            https://scipy-cookbook.readthedocs.io/items/Matplotlib_Show_colormaps.html .
         col_bounds: array_like, optional
             Limits ([min, max]) the values over which the colormap spans to
             these values.  Useful for sampling an entire colormap over a range
@@ -698,7 +698,7 @@ class ColorTransferFunction(MultiVariateTransferFunction):
             Larger values will be more opaque.
         colormap : string, optional
             An acceptable colormap.  See either yt.visualization.color_maps or
-            http://www.scipy.org/Cookbook/Matplotlib/Show_colormaps .
+            https://scipy-cookbook.readthedocs.io/items/Matplotlib_Show_colormaps.html .
         scale_func: function(:obj:`!value`, :obj:`!minval`, :obj:`!maxval`), optional
             A user-defined function that can be used to scale the alpha channel
             as a function of the TransferFunction field values. Function maps
@@ -765,7 +765,7 @@ class ColorTransferFunction(MultiVariateTransferFunction):
             set as 1.0 everywhere.
         colormap : string, optional
             An acceptable colormap.  See either yt.visualization.color_maps or
-            http://www.scipy.org/Cookbook/Matplotlib/Show_colormaps .
+            https://scipy-cookbook.readthedocs.io/items/Matplotlib_Show_colormaps.html .
         col_bounds: array_like, optional
             Limits ([min, max]) the values over which the colormap spans to
             these values.  Useful for sampling an entire colormap over a range
